===============================
kinparse
===============================

.. image:: https://img.shields.io/pypi/v/kinparse.svg
        :target: https://pypi.python.org/pypi/kinparse

This is a parser for KiCad V5 and V6 schematic netlist files that are output by EESCHEMA.
Just pass a file containing a netlist to the `parse_netlist()` function and
it will deliver a `pyparsing object <https://pypi.python.org/pypi/pyparsing>`_
containing all the netlist's information.

* Free software: MIT license
* Documentation: http://devbisme.github.io/kinparse
